@@ -27,6 +27,16 @@ class ApiSpaces(ApiBase):
             "spaces/{space_name}/cloud_accounts/{cloud_account}".format(**locals())
         )
 
+    def space_cloud_account_compute_services(self, space_name: str, cloud_account: str):
+        return self.build_route(
+            "spaces/{space_name}/cloud_accounts/{cloud_account}/compute_services".format(**locals())
+        )
+
+    def space_cloud_account_compute_service(self, space_name: str, cloud_account: str, compute_service: str):
+        return self.build_route(
+            "spaces/{space_name}/cloud_accounts/{cloud_account}/compute_services/{compute_service}".format(**locals())
+        )
+
     def space_github_repositories(self, space_name: str):
         return self.build_route(
             "spaces/{space_name}/repositories/github".format(**locals())
