@@ -7,14 +7,16 @@ import time
 from isodate import duration_isoformat
 
 from gateways.apis.api_route_base import ApiRoot
-from gateways.common.cs18_api_classes import BlueprintRepositoryDetails, AccessLink
+from gateways.common.cs18_api_classes import BlueprintRepositoryDetails, AccessLink, \
+    AddAccountBlueprintRepositoryRequest
 from gateways.common.cs18_api_converters import Converters
-from gateways.common.cs18_api_errors import UnauthorizedException, MaxRetriesException, SandboxNotFound, \
+from gateways.common.cs18_api_errors import UnauthorizedException, SandboxNotFound, \
     SandboxEndingFailed
 from gateways.common.cs18_api_requests import (
     CreateInvitationsRequest,
     UpdateSpaceRequest,
-    ProductionEnvironment, DebuggingServiceValue, SpaceCloudAccountInfraSettingsRequest)
+    ProductionEnvironment, DebuggingServiceValue, SpaceCloudAccountInfraSettingsRequest,
+    AddK8SComputeServiceToSpaceRequest, UpdateK8SComputeServiceInSpaceRequest)
 from gateways.common.cs18_api_responses import (AccountStatusResponse, BlueprintFileResponse, BlueprintResponse,
                                                 CatalogForGetAllResponse, CatalogForGetResponse, CloudAccountResponse,
                                                 CreateProductionResponse, CreateSandboxResponse, GetSpaceResponse,
@@ -23,7 +25,8 @@ from gateways.common.cs18_api_responses import (AccountStatusResponse, Blueprint
                                                 SandboxResponse, SandboxResponseLean, TokenResponse,
                                                 UserInvitationResponse, UserPermittedToSpaceResponse,
                                                 UserForAllUsersResponse, CloudAccountInSpaceResponse, RegionResponse,
-                                                VerifyCloudProviderResponse)
+                                                VerifyCloudProviderResponse, AccountRepositoryResponse,
+                                                BlueprintValidationResponse)
 from gateways.n_session import NSession
 from gateways.the_gateway import TheGateway
 from gateways.utils import GatewayUtils, Utils
@@ -31,6 +34,7 @@ from gateways.utils import GatewayUtils, Utils
 
 class Colony:
     # pylint: disable=too-many-public-methods
+    # pylint: disable=too-many-lines
     def __init__(self, account: str, **kwargs):
         """
         :param account: account name
@@ -84,7 +88,6 @@ class Colony:
             api_address=self.api_address, space=self.space, version=self._api_version
         )
 
-
     def change_space(self, space: str):
         self.space = space
         self._api_root = ApiRoot(
@@ -188,7 +191,7 @@ class Colony:
         request = {
             "kube_config": kube_config,
             "name": name,
-            "cloud_account_name": cloud_account_name,
+            "cloud_account_name": cloud_account_name
         }
 
         resp = self.session.post(url=method_url, json=request)
@@ -199,12 +202,22 @@ class Colony:
         request = {
             "kube_config": kube_config,
             "name": name,
-            "cloud_account_name": cloud_account_name,
+            "cloud_account_name": cloud_account_name
         }
 
         resp = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
+    def get_k8s_agent_deployment_yaml(self, cloud_account_name: str, compute_service_name: str, agent_namespace: str,
+                                      sandbox_namespaces: List[str]):
+        method_url = self._api_root.settings.k8s_agent_deployment_yaml(cloud_account_name=cloud_account_name,
+                                                                       compute_service_name=compute_service_name,
+                                                                       agent_namespace=agent_namespace,
+                                                                       sandbox_namespaces=','.join(sandbox_namespaces))
+        resp = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        return resp.text
+
     def update_aws_account(self, arn_role: str, external_id: str, name: str):
         """ Register AWS
         :param arn_role: IAM role ARN required for assume role to the customer cloud account
@@ -578,18 +591,38 @@ class Colony:
         production_response = Converters.create_production_green_response(json_result)
         return production_response
 
+    def add_repository_to_account(self, request: AddAccountBlueprintRepositoryRequest):
+        method_url = self._api_root.settings.add_repository_by_token()
+        resp = self.session.post(url=method_url, json=request.__dict__)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def get_account_repositories(self) -> List[AccountRepositoryResponse]:
+        url = self._api_root.settings.repositories()
+        response = self.session.get(url=url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+
+        repositories_json = json.loads(response.text)
+        return [Converters.create_account_repository_response(repository) for repository in repositories_json]
+
+    def delete_account_repository(self, name: str):
+        method_url = self._api_root.settings.repository(name)
+        resp = self.session.delete(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
     def add_repository_to_space(
             self,
             repository_details: BlueprintRepositoryDetails,
             deployment_type: str = None,
             wait_for_cache_refresh: bool = False,
     ):
+        print(f'repository_url: {repository_details.repository_url} access_token: {repository_details.access_token}')
         method_url = self._api_root.spaces.space_repositories(space_name=self.space)
         request = {
             "repository_url": repository_details.repository_url,
             "access_token": repository_details.access_token,
             "repository_type": repository_details.repository_type,
-            "type": deployment_type,
+            "branch": repository_details.branch,
+            "type": deployment_type
         }
         resp = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
@@ -621,19 +654,18 @@ class Colony:
         GatewayUtils.handle_response(response=resp, return_codes=[200])
         return resp.content
 
-    def validate_blueprint(self, blueprint: str, branch: str = None) -> bool:
-        method_url = "{base}?blueprint={blueprint}&branch={branch}".format(
-            base=self._api_root.blueprint_validation.blueprint_validation_by_space_name(
-                space_name=self.space
-            ),
-            blueprint=blueprint,
-            branch=branch if branch else "master",
-        )
-        resp = self.session.get(url=method_url)
-        GatewayUtils.handle_response(response=resp, return_codes=[200])
-        if resp.json() == {"errors": []}:
-            return True
-        return resp.json()
+    def validate_blueprint(self, blueprint: str, deployment_type: str = 'sandbox', branch: str = None,
+                           commit: str = None) -> BlueprintValidationResponse:
+        method_url = self._api_root.blueprint_validation.blueprint_validation_by_space_name(space_name=self.space)
+        request = {"blueprint_name": blueprint,
+                   "type": deployment_type}
+        if branch or commit:
+            request['source'] = {"branch": branch,
+                                 "commit": commit}
+        response = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+        json_result = json.loads(response.text)
+        return Converters.create_blueprint_validation_response(json_result)
 
     def invite_user(self, invites: CreateInvitationsRequest):
         method_url = self._api_root.account.invitations()
@@ -802,6 +834,27 @@ class Colony:
             Converters.create_cloud_account_in_space_response(x) for x in json.loads(res.text)
         ]
 
+    def add_compute_service_to_space(self, cloud_account: str, request: AddK8SComputeServiceToSpaceRequest):
+        method_url = self._api_root.spaces.space_cloud_account_compute_services(space_name=self.space,
+                                                                                cloud_account=cloud_account)
+        res = self.session.post(url=method_url, json=request.__dict__)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+
+    def update_compute_service_in_space(self, cloud_account: str, compute_service: str,
+                                        request: UpdateK8SComputeServiceInSpaceRequest):
+        method_url = self._api_root.spaces.space_cloud_account_compute_service(space_name=self.space,
+                                                                               cloud_account=cloud_account,
+                                                                               compute_service=compute_service)
+        res = self.session.put(url=method_url, json=request.__dict__)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+
+    def remove_compute_service_from_space(self, cloud_account: str, compute_service: str):
+        method_url = self._api_root.spaces.space_cloud_account_compute_service(space_name=self.space,
+                                                                               cloud_account=cloud_account,
+                                                                               compute_service=compute_service)
+        res = self.session.delete(url=method_url)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+
     def get_account_users(self) -> List[UserForAllUsersResponse]:
         method_url = self._api_root.account.account_users()
         res = self.session.get(url=method_url)
@@ -877,10 +930,7 @@ class Colony:
         res = self.session.delete(url=method_url)
         GatewayUtils.handle_response(response=res, return_codes=[200])
 
-    def add_artifactory_repo(self,
-                             server_url: str,
-                             artifactory_username: str,
-                             api_key: str):
+    def add_artifactory_repo(self, server_url: str, artifactory_username: str, api_key: str):
         method_url = self._api_root.artifacts_repository.artifactory(space_name=self.space)
         request = {
             "server_url": server_url,
@@ -888,8 +938,7 @@ class Colony:
             "api_key": api_key
         }
         response = self.session.post(url=method_url, json=request)
-        GatewayUtils.handle_response(response=response,
-                                     return_codes=[200])
+        GatewayUtils.handle_response(response=response, return_codes=[200])
 
     def get_cost_breakdown(self, frm: datetime, until: datetime, criteria: str = 'blueprint') -> dict:
         url = self._api_root.cost.breakdown(space_name=self.space, frm=frm, until=until, criteria=criteria)
@@ -906,12 +955,23 @@ class Colony:
     def post_request(self, url: str, request_json: dict, return_codes: List = None):
         return_codes = return_codes or [200]
         response = self.session.post(url=url, json=request_json)
-        GatewayUtils.handle_response(response=response,
-                                     return_codes=return_codes)
+        GatewayUtils.handle_response(response=response, return_codes=return_codes)
 
-    def set_account_sso_enabled(self, account_name: str, enabled: bool):
-        sso_enabled_url = self._api_root.account.set_sso_enabled(account_name)
-        self.post_request(sso_enabled_url, {"enabled": enabled}, return_codes=[200])
+    def put_request(self, url: str, request_json: dict, return_codes: List = None):
+        return_codes = return_codes or [200]
+        response = self.session.put(url=url, json=request_json)
+        GatewayUtils.handle_response(response=response, return_codes=return_codes)
+
+    def set_account_extra_details(self, account_name: str, sso_enabled: bool, anonymous_users: bool):
+        set_account_extra_details_url = self._api_root.account.set_account_extra_details(account_name)
+        self.put_request(set_account_extra_details_url, {"sso_enabled": sso_enabled, "anonymous_users": anonymous_users}
+                         , return_codes=[200])
+
+    def get_account_extra_details(self, account_name: str):
+        set_account_extra_details_url = self._api_root.account.set_account_extra_details(account_name)
+        response = self.session.get(url=set_account_extra_details_url)
+        GatewayUtils.handle_response(response, [200])
+        return json.loads(response.text)
 
     def get_space_cloud_account_regions(self, space_name: str, cloud_account_name: str) -> List[RegionResponse]:
         method_url = self._api_root.spaces.space_cloud_account_regions(space_name=space_name,
@@ -955,9 +1015,9 @@ class SandboxCleaner:
 
     def __exit__(self, exc_type, exc_val: str, exc_tb):
         for sandbox in self.sandboxes.sandboxes_set:
-            if exc_type is MaxRetriesException:
-                print(f"Sandbox {sandbox} failed on timeout")
-            elif exc_type is SandboxNotFound:
+            # if exc_type is MaxRetriesException:
+            #     print(f"Sandbox {sandbox} failed on timeout")
+            if exc_type is SandboxNotFound:
                 print(f"Sandbox {sandbox} failed on not found")
             elif exc_type is SandboxEndingFailed:
                 print(f"Sandbox {sandbox} failed to end")
