@@ -1,7 +1,7 @@
 from typing import List, Optional
 from datetime import datetime
 import dateutil.parser
-from gateways.common.cs18_api_classes import CloudComputeService, AccessLink, CloudAccountCostResponse
+from gateways.common.cs18_api_classes import AccessLink
 from gateways.common.cs18_api_errors import SandboxError, Error
 from gateways.common.cs18_api_responses import (
     SpaceAdmin,
@@ -43,7 +43,10 @@ from gateways.common.cs18_api_responses import (
     BlueprintServiceResponse,
     LaunchingProgress, LaunchingProgressStep, CloudAccountInSpaceResponse, CloudAccountConnectivityResponse,
     CloudAccountInfraSetResponse, CloudAccountSubnetsResponse, RegionResponse, GetImagesResponse,
-    VerifyCloudProviderResponse, VerifyCloudProviderResourceResponse)
+    VerifyCloudProviderResponse, VerifyCloudProviderResourceResponse, AccountRepositoryResponse,
+    BlueprintValidationResponse, BlueprintValidationSourceResponse, CloudAccountCostResponse,
+    ComputeServiceInAccountResponse, ComputeServiceInSpaceResponse, ComputeServiceSpaceSpecResponse,
+    K8SComputeServiceSpaceInfraSettingsResponse, BlueprintComputeServiceResponse)
 
 
 class Converters:
@@ -136,6 +139,30 @@ class Converters:
             ),
         )
 
+    @staticmethod
+    def create_blueprint_validation_response(blueprint: dict) -> BlueprintValidationResponse:
+        return BlueprintValidationResponse(
+            name=blueprint["blueprint_name"],
+            description=blueprint["description"],
+            url=blueprint["url"],
+            source=Converters.create_blueprint_validation_source_response(blueprint.get("source")),
+            artifacts=blueprint.get("artifacts", {}),
+            inputs=[Converters._create_blueprint_input_response(i) for i in blueprint.get("inputs") or []],
+            errors=[Error(e) for e in blueprint["errors"]],
+            services=[Converters._create_blueprint_service_response(x) for x in blueprint.get("services") or []],
+            applications=[Converters._create_blueprint_app_response(x) for x in blueprint.get("applications") or []],
+            clouds=[Converters._create_blueprint_cloud_response(cloud) for cloud in blueprint.get("clouds") or []]
+        )
+
+    @staticmethod
+    def create_blueprint_validation_source_response(source: dict) -> Optional[BlueprintValidationSourceResponse]:
+        if not source:
+            return None
+        return BlueprintValidationSourceResponse(
+            branch=source.get("branch"),
+            commit=source.get("commit")
+        )
+
     @staticmethod
     def create_blueprint_response(blueprint: dict) -> BlueprintResponse:
         """
@@ -195,21 +222,57 @@ class Converters:
         return [Error(e) for e in errors]
 
     @staticmethod
-    def _create_compute_services_response(
+    def _create_compute_services_in_account_response(
             cloud_compute_services: List[dict]
-    ) -> List[CloudComputeService]:
+    ) -> List[ComputeServiceInAccountResponse]:
         compute_services = [
-            CloudComputeService(
+            ComputeServiceInAccountResponse(
                 name=compute_service.get("name", None),
                 service_type=compute_service.get("type", None),
                 created_date=Converters._parse_datetime(compute_service.get("created_date", None)),
                 created_by=compute_service.get("created_by", None),
                 user_defined=compute_service.get("user_defined", None),
+                spaces=compute_service.get("spaces", [])
             )
             for compute_service in cloud_compute_services
         ]
         return compute_services
 
+    @staticmethod
+    def _create_compute_services_in_space_response(
+            cloud_compute_services: List[dict]
+    ) -> List[ComputeServiceInSpaceResponse]:
+        compute_services = [
+            ComputeServiceInSpaceResponse(
+                name=compute_service.get("name", None),
+                service_type=compute_service.get("type", None),
+                created_date=Converters._parse_datetime(compute_service.get("created_date", None)),
+                created_by=compute_service.get("created_by", None),
+                user_defined=compute_service.get("user_defined", None),
+                spec=Converters._create_compute_service_space_spec_response(compute_service.get("spec"))
+            )
+            for compute_service in cloud_compute_services
+        ]
+        return compute_services
+
+    @staticmethod
+    def _create_compute_service_space_spec_response(spec: dict) -> Optional[ComputeServiceSpaceSpecResponse]:
+        if spec is None:
+            return None
+        return ComputeServiceSpaceSpecResponse(
+            kubernetes=Converters._create_k8s_compute_service_space_infra_settings_response(spec.get("kubernetes"))
+        )
+
+    @staticmethod
+    def _create_k8s_compute_service_space_infra_settings_response(kubernetes: dict) \
+            -> Optional[K8SComputeServiceSpaceInfraSettingsResponse]:
+        if kubernetes is None:
+            return None
+        return K8SComputeServiceSpaceInfraSettingsResponse(
+            namespace=kubernetes.get("namespace"),
+            internet_facing=kubernetes.get("internet_facing")
+        )
+
     @staticmethod
     def create_cloud_account_response(cloud: dict) -> CloudAccountResponse:
         """
@@ -223,7 +286,7 @@ class Converters:
             created_date=Converters._parse_datetime(cloud.get("created_date")),
             created_by=cloud["created_by"],
             spaces=cloud["spaces"],
-            compute_services=Converters._create_compute_services_response(
+            compute_services=Converters._create_compute_services_in_account_response(
                 cloud.get("compute_services", None)
             ),
             cost=Converters._create_cloud_account_cost_response(cloud),
@@ -244,7 +307,7 @@ class Converters:
             created_by=cloud["created_by"],
             internet_facing=cloud["internet_facing"],
             connectivity=Converters._create_cloud_account_connectivity_response(cloud.get("connectivity")),
-            compute_services=Converters._create_compute_services_response(
+            compute_services=Converters._create_compute_services_in_space_response(
                 cloud.get("compute_services", None)
             ),
             cost=Converters._create_cloud_account_cost_response(cloud),
@@ -603,6 +666,7 @@ class Converters:
             region=Converters._create_blueprint_cloud_region_response(
                 cloud.get("region")
             ),
+            compute_service=Converters._create_blueprint_compute_service(cloud.get("compute_service"))
         )
 
     @staticmethod
@@ -810,3 +874,22 @@ class Converters:
             success=verify["success"],
             resources_summary=Converters._create_resources_summary_response(verify["resources_summary"]),
         )
+
+    @staticmethod
+    def create_account_repository_response(data: dict) -> AccountRepositoryResponse:
+        return AccountRepositoryResponse(name=data['name'],
+                                         allow_sharing=data['allow_sharing'],
+                                         open_access=data['open_access'],
+                                         repository_url=data['repository_url'],
+                                         repository_type=data['repository_type'],
+                                         errors=[Error(e) for e in data["errors"]])
+
+    @staticmethod
+    def _create_blueprint_compute_service(compute_service: dict) -> BlueprintComputeServiceResponse:
+        return BlueprintComputeServiceResponse(
+            name=compute_service.get("name", None),
+            service_type=compute_service.get("type", None),
+            created_date=Converters._parse_datetime(compute_service.get("created_date", None)),
+            created_by=compute_service.get("created_by", None),
+            user_defined=compute_service.get("user_defined", None)
+        )
