@@ -5,12 +5,18 @@ Container for Response objects used in cs18-api-client
 import abc
 
 from datetime import datetime
-from typing import List, Dict
+from typing import List, Dict, Optional
 
-from gateways.common.cs18_api_classes import AccessLink, CloudComputeService, CloudAccountCostResponse
+from gateways.common.cs18_api_classes import AccessLink
 from gateways.common.cs18_api_errors import SandboxError, Error
 
 
+class BlueprintValidationSourceResponse:
+    def __init__(self, branch: str, commit: str):
+        self.commit = commit
+        self.branch = branch
+
+
 class AccountStatusUserDetails:
     def __init__(self, user_details: {}):
         self.last_name = user_details["last_name"]
@@ -142,13 +148,24 @@ class BlueprintRegionResponse:
         self.region_id = region_id
 
 
+class BlueprintComputeServiceResponse:
+    def __init__(self, name: str, service_type: str, created_date: datetime, created_by: str, user_defined: bool):
+        self.name = name
+        self.type = service_type
+        self.created_date = created_date
+        self.created_by = created_by
+        self.user_defined = user_defined
+
+
 class BlueprintCloudResponse:
     def __init__(
-            self, provider: str, cloud_account_name: str, region: BlueprintRegionResponse
+            self, provider: str, cloud_account_name: str, region: BlueprintRegionResponse,
+            compute_service: BlueprintComputeServiceResponse
     ):
         self.provider = provider
         self.cloud_account_name = cloud_account_name
         self.region = region
+        self.compute_service = compute_service
 
 
 class ArtifactRepoCreatedUser:
@@ -676,6 +693,37 @@ class UserPermittedToSpaceResponse:
         self.has_access_to_all_spaces = has_access_to_all_spaces
 
 
+class CloudAccountCostResponse:
+    def __init__(self, last_update: Optional[datetime]):
+        self.last_update = last_update
+
+
+class ComputeServiceBaseResponse:
+    def __init__(self,
+                 name: str,
+                 service_type: str,
+                 created_date: datetime,
+                 created_by: str,
+                 user_defined: bool):
+        self.created_by = created_by
+        self.type = service_type
+        self.created_date = created_date
+        self.name = name
+        self.user_defined = user_defined
+
+
+class ComputeServiceInAccountResponse(ComputeServiceBaseResponse):
+    def __init__(self,
+                 name: str,
+                 service_type: str,
+                 created_date: datetime,
+                 created_by: str,
+                 user_defined: bool,
+                 spaces: List[str]):
+        super().__init__(name, service_type, created_date, created_by, user_defined)
+        self.spaces = spaces
+
+
 class CloudAccountResponse:
     def __init__(
             self,
@@ -684,7 +732,7 @@ class CloudAccountResponse:
             created_date: datetime,
             created_by: str,
             spaces: List[str],
-            compute_services: List[CloudComputeService] = None,
+            compute_services: List[ComputeServiceInAccountResponse] = None,
             cost: CloudAccountCostResponse = None,
             errors: List[Error] = None
     ):
@@ -725,6 +773,31 @@ class CloudAccountConnectivityResponse:
         self.existing_infra_sets = existing_infra_sets
 
 
+class K8SComputeServiceSpaceInfraSettingsResponse:
+    def __init__(self, namespace: str, internet_facing: bool):
+        self.namespace = namespace
+        self.internet_facing = internet_facing
+
+
+class ComputeServiceSpaceSpecResponse:
+    def __init__(self, kubernetes: Optional[K8SComputeServiceSpaceInfraSettingsResponse]):
+        self.kubernetes = kubernetes
+
+
+class ComputeServiceInSpaceResponse(ComputeServiceBaseResponse):
+    def __init__(
+            self,
+            name: str,
+            service_type: str,
+            created_date: datetime,
+            created_by: str,
+            user_defined: bool,
+            spec: Optional[ComputeServiceSpaceSpecResponse]
+    ):
+        super().__init__(name, service_type, created_date, created_by, user_defined)
+        self.spec = spec
+
+
 class CloudAccountInSpaceResponse:
     def __init__(
             self,
@@ -734,7 +807,7 @@ class CloudAccountInSpaceResponse:
             created_by: str,
             internet_facing: bool,
             connectivity: CloudAccountConnectivityResponse,
-            compute_services: List[CloudComputeService] = None,
+            compute_services: List[ComputeServiceInSpaceResponse] = None,
             cost: CloudAccountCostResponse = None,
             errors: List[Error] = None,
     ):
@@ -861,3 +934,42 @@ class VerifyCloudProviderResponse:
                  resources_summary: List[VerifyCloudProviderResourceResponse] = None):
         self.success = success
         self.resources_summary = resources_summary
+
+
+class AccountRepositoryResponse:
+    def __init__(self, name: str,
+                 allow_sharing: bool,
+                 open_access: bool,
+                 repository_url: str,
+                 repository_type: str,
+                 errors: []):
+        self.repository_name = name
+        self.allow_sharing = allow_sharing
+        self.open_access = open_access
+        self.repository_url = repository_url
+        self.repository_type = repository_type
+        self.errors = errors
+
+
+class BlueprintValidationResponse:
+    def __init__(self,
+                 name: str,
+                 description: str,
+                 url: str,
+                 source: BlueprintValidationSourceResponse,
+                 artifacts: Dict[str, str],
+                 inputs: List[BlueprintInputResponse],
+                 errors: List[Error],
+                 services: List[BlueprintServiceResponse],
+                 applications: List[BlueprintApplicationResponse],
+                 clouds: List[BlueprintCloudResponse]):
+        self.name = name
+        self.description = description
+        self.url = url
+        self.source = source
+        self.artifacts = artifacts
+        self.inputs = inputs
+        self.errors = errors
+        self.services = services
+        self.applications = applications
+        self.clouds = clouds
